@@ -20,6 +20,8 @@
 
 #include <hildon/hildon.h>
 #include <libhildondesktop/libhildondesktop.h>
+#include <mce/dbus-names.h>
+#include <mce/mode-names.h>
 #include <icd/osso-ic-ui-dbus.h>
 #include <icd/osso-ic-dbus.h>
 #include "connectnow-home-widget.h"
@@ -272,6 +274,38 @@ connect_now_disconnect_current_connection(ConnectNowHomePlugin* desktop_plugin)
   dbus_message_unref(message);
 }
 
+static void
+connect_now_switch_normal_mode(ConnectNowHomePlugin* desktop_plugin)
+{
+  DBusGConnection* dbus_conn = hd_home_plugin_item_get_dbus_g_connection(HD_HOME_PLUGIN_ITEM(desktop_plugin),
+									 DBUS_BUS_SYSTEM,
+									 NULL);
+  DBusGProxy *proxy = dbus_g_proxy_new_for_name(dbus_conn,
+						MCE_SERVICE,
+						MCE_REQUEST_PATH,
+						MCE_REQUEST_IF);
+
+  gchar* dev_mode = NULL;
+  dbus_g_proxy_call(proxy,
+					MCE_DEVICE_MODE_GET,
+					NULL,
+					G_TYPE_INVALID,
+					G_TYPE_STRING,
+					&dev_mode,
+					G_TYPE_INVALID);
+
+  if(g_str_equal(dev_mode, MCE_FLIGHT_MODE))
+   dbus_g_proxy_call_no_reply(proxy,
+						 	  MCE_DEVICE_MODE_CHANGE_REQ,
+						 	  G_TYPE_STRING,
+						 	  MCE_NORMAL_MODE MCE_CONFIRM_SUFFIX,
+						 	  G_TYPE_INVALID);
+
+  g_free(dev_mode);
+  g_object_unref(proxy);
+  dbus_g_connection_unref(dbus_conn);
+}
+
 static gint
 connect_now_button_press(GtkWidget* widget, GdkEventButton *event, ConnectNowHomePlugin* desktop_plugin)
 {
@@ -302,6 +336,7 @@ connect_now_button_press(GtkWidget* widget, GdkEventButton *event, ConnectNowHom
   }
   else
   {
+    connect_now_switch_normal_mode(desktop_plugin);
     con_ic_connection_connect_by_id(desktop_plugin->con, 
 				    desktop_plugin->connection_id,
 				    CON_IC_CONNECT_FLAG_NONE);
